Index: pbx/pbx_config.c
===================================================================
--- pbx/pbx_config.c	(revision 16545)
+++ pbx/pbx_config.c	(working copy)
@@ -1643,7 +1643,19 @@
 				cxt = ast_category_browse(cfg, cxt);
 				continue;
 			}
-			if ((con=ast_context_create(&local_contexts,cxt, registrar))) {
+			con = NULL;
+			if (cxt[0] == '+') {
+				/* [+context] syntax means adding on to an existing context */
+				/* this is helpful when using #include to organise/assemble your dial plan */
+				con = ast_context_find_local(local_contexts, &cxt[1]);
+				if (!con) {
+					ast_log(LOG_WARNING, "[%s] used to request append, but context not found so creating it anyway\n", cxt);
+					con = ast_context_create(&local_contexts, &cxt[1], registrar);
+				}
+			} else {
+				con = ast_context_create(&local_contexts,cxt, registrar);
+			}
+			if (con) {
 				v = ast_variable_browse(cfg, cxt);
 				while(v) {
 					if (!strcasecmp(v->name, "exten")) {
Index: include/asterisk/pbx.h
===================================================================
--- include/asterisk/pbx.h	(revision 16545)
+++ include/asterisk/pbx.h	(working copy)
@@ -206,6 +206,16 @@
  */
 struct ast_context *ast_context_find(const char *name);
 
+/*! Find a context in any context list*/
+/*!
+ * \param contexts_head is the head of the contexts chan to search
+ * \param name name of the context to find
+ * Will search for the context with the given name.
+ * Returns the ast_context on success, NULL on failure.
+ * ast_context_find_local is used whilst extensions.conf is reloaded
+ */
+struct ast_context *ast_context_find_local(struct ast_context *contexts_head, const char *name);
+
 enum ast_pbx_result {
 	AST_PBX_SUCCESS = 0,
 	AST_PBX_FAILED = -1,
Index: pbx.c
===================================================================
--- pbx.c	(revision 16545)
+++ pbx.c	(working copy)
@@ -744,6 +744,20 @@
 	return tmp;
 }
 
+struct ast_context *ast_context_find_local(struct ast_context *contexts_head, const char *name)
+{
+	struct ast_context *tmp;
+	tmp = contexts_head;
+	if (name) {
+		while (tmp) {
+			if (!strcasecmp(name, tmp->name))
+				break;
+			tmp = tmp->next;
+		}
+	}
+	return tmp;
+}
+
 #define STATUS_NO_CONTEXT	1
 #define STATUS_NO_EXTENSION	2
 #define STATUS_NO_PRIORITY	3
